To prevent the automated abuse of a page, applications can implement
what is known as a CAPTCHA.

These are used to ensure human
interaction with the application and are often used on forms where the
application conducts sensitive actions. These typically include user
registration, or submitting emails via "Contact Us" pages etc.
The tool has flagged this not as a vulnerability, but as a prompt for
the penetration tester to conduct further manual testing on the
CAPTCHA function, as The tool cannon audit CAPTCHA protected forms.
Testing for insecurely implemented CAPTCHA is a manual process, and an
insecurely implemented CAPTCHA could allow a cyber-criminal a means to
abuse these sensitive actions.